Enum Ovrmod
#[repr(u8)]pub enum Ovrmod {
Preserve = 0,
Overwrite = 1,
}Variants
Preserve = 0
DR register is preserved with the old data when an overrun is detected
Overwrite = 1
DR register is overwritten with the last conversion result when an overrun is detected
Implementations